@@ -8,7 +8,7 @@ log = logging.getLogger(__name__)
 
 
 @hookimpl
-def pylsp_references(document, position, exclude_declaration=False):
+def pylsp_references(document, position, exclude_declaration):
     code_position = _utils.position_to_jedi_linecolumn(document, position)
     usages = document.jedi_script().get_references(**code_position)
 
